@@ -12,12 +12,13 @@ async fn pubsub_test() {
     let secret: u8 = rand::thread_rng().gen();
 
     let producer = spawn(async move {
-        sleep(Duration::from_millis(500)).await;
+        sleep(Duration::from_millis(200)).await;
+
         assert!(STATE.set(secret).is_ok());
         assert_eq!(STATE.set(secret), Err(secret));
     });
 
-    let consumers = (0..16).map(|_| {
+    let fast_consumers = (0..16).map(|_| {
         spawn(async move {
             assert!(STATE.try_get().is_none());
 
@@ -26,5 +27,18 @@ async fn pubsub_test() {
         })
     });
 
-    futures::join!(producer, future::join_all(consumers));
+    let slow_consumers = (0..16).map(|_| {
+        spawn(async move {
+            sleep(Duration::from_millis(500)).await;
+
+            let received = *STATE.get().await;
+            assert_eq!(received, secret);
+        })
+    });
+
+    futures::join!(
+        producer,
+        future::join_all(fast_consumers),
+        future::join_all(slow_consumers)
+    );
 }
